

#ifndef __patcher_h__
#define __patcher_h__

void PatchLoad(LispChar * aFileContent, LispOutput& aOutput,
               LispEnvironment& aEnvironment);

#endif

